@@ -80,7 +80,7 @@ class UpdateELKAPI:
             list_columns.append(modual_name)
             merge_data[modual_name_column] = self.table_reason[modual_name_column](merge_data[modual_name_column])
             merge_data[modual_name_column] = merge_data[modual_name_column].astype(str)
-            merge_data[modual_name_column + '_'] = np.where(merge_data[modual_name + '_score'] > 0.5, merge_data[modual_name_column], 'nan')
+            merge_data[modual_name_column + '_'] = np.where(merge_data[modual_name + '_score'] > self.abnormal_threshold, merge_data[modual_name_column], 'nan')
             list_columns_.append(modual_name_column + '_')
         merge_data['abnormal_reason_'] = merge_data[list_columns_].agg(', '.join, axis=1)
         merge_data['abnormal_reason_'] = merge_data['abnormal_reason_'].str.replace(' nan,', '')
