@@ -258,15 +258,20 @@ class GetConfArg:
         self.appollo_info = {
             "servers": bootstrap_servers,
             "customer_id": get_apollo_value(apollo_client, "CUSTOMER_ID", APOLLO_NAMESPACE_MODAL),
+            "tag": get_apollo_value(apollo_client, "tag", APOLLO_NAMESPACE_MODAL),
+            "PROFILE_ID": get_apollo_value(apollo_client, "PROFILE_ID", APOLLO_NAMESPACE_MODAL),
             "model_id": get_apollo_value(apollo_client, "MODEL_ID", APOLLO_NAMESPACE_MODAL),
             "training_id": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
             "topic": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
             "BATCH_SIZE": int(get_apollo_value(apollo_client, "BATCH_SIZE", APOLLO_NAMESPACE_MODAL)),
+            "TRUE_LABEL_COLUMN": get_apollo_value(apollo_client, "TRUE_LABEL_COLUMN", APOLLO_NAMESPACE_MODAL),
 
-            "dataset_path": get_apollo_value(apollo_client, "SOURCE_PATH_DATASET", APOLLO_NAMESPACE_MODAL),
-            "kg_path": get_apollo_value(apollo_client, "SOURCE_PATH_KNOWLEDGE", APOLLO_NAMESPACE_MODAL),
-            "lib_path": get_apollo_value(apollo_client, "SOURCE_PATH_LIB", APOLLO_NAMESPACE_MODAL),
-            "KAFKA_USE": get_apollo_value(apollo_client, "KAFKA_USE", APOLLO_NAMESPACE_MODAL),
+            # "dataset_path": get_apollo_value(apollo_client, "SOURCE_PATH_DATASET", APOLLO_NAMESPACE_MODAL),
+            "kg_path": config('SOURCE_PATH_KNOWLEDGE'),
+            "lib_path": config('SOURCE_PATH_LIB'),
+            # "kg_path": get_apollo_value(apollo_client, "SOURCE_PATH_KNOWLEDGE", APOLLO_NAMESPACE_MODAL),
+            # "lib_path": get_apollo_value(apollo_client, "SOURCE_PATH_LIB", APOLLO_NAMESPACE_MODAL),
+            # "KAFKA_USE": get_apollo_value(apollo_client, "KAFKA_USE", APOLLO_NAMESPACE_MODAL),
             "DB_ENGINE": get_apollo_value(apollo_client, "DB_ENGINE", APOLLO_NAMESPACE_INF),
             "DB_USERNAME": get_apollo_value(apollo_client, "DB_USERNAME", APOLLO_NAMESPACE_INF),
             "DB_PASS": password,
@@ -306,8 +311,8 @@ TRAINING_REASON : %s
             "customer_id_lst": self.appollo_info["customer_id"],
             "training_id_lst": self.appollo_info["training_id"],
             "model_id_lst": self.appollo_info["model_id"],
-            "profile_id_lst": self.appollo_info["customer_id"],
-            "tag_lst": self.appollo_info["customer_id"],
+            "profile_id_lst": self.appollo_info["PROFILE_ID"],
+            "tag_lst": self.appollo_info["tag"],
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
@@ -361,8 +366,8 @@ TRAINING_REASON : %s
             "customer_id_lst": self.appollo_info["customer_id"],
             "training_id_lst": self.appollo_info["training_id"],
             "model_id_lst": self.appollo_info["model_id"],
-            "profile_id_lst": self.appollo_info["customer_id"],
-            "tag_lst": self.appollo_info["customer_id"],
+            "profile_id_lst": self.appollo_info["PROFILE_ID"],
+            "tag_lst": self.appollo_info["tag"],
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
@@ -391,7 +396,7 @@ TRAINING_REASON : %s
                 self.read_train_conf_apollo()
             t1 = time.time()
             self.training_start_time_lst = datetime.datetime.now()
-            self.dict_report = self.dict_model.train()
+            self.dict_report = self.dict_model.train(chunksize=self.appollo_info["BATCH_SIZE"], true_lable_name=self.appollo_info["TRUE_LABEL_COLUMN"])
             self.total_training_time_lst = time.time() - t1
             self.training_end_time_lst = datetime.datetime.now()
             self.DATA_START_DATE = self.dict_model.DATA_START_DATE
@@ -440,10 +445,9 @@ TRAINING_REASON : %s
         )
         with open(path, 'a') as f:
             f.write(output_txt + "\n")
-        
+
 
 if __name__ == '__main__':
-    from hitrustai_lab.model_train.ai_module_train import TrainModelToSQl
     dict_add_column = {
         "add_column1": Column("add_column1", Integer, primary_key=True),
         "add_column2": Column("add_column2", Integer, primary_key=True)
