@@ -1,5 +1,6 @@
 import pandas as pd
 import pickle
+import glob
 from sklearn import metrics
 from ctypes import cdll, c_char_p
 from sqlalchemy import create_engine
@@ -80,19 +81,24 @@ class AITrainUtilsAPI:
         f1 = round(metrics.f1_score(test_y, test_y_predicted), 2)
         return self.report("4007", accuracy, precision, recall, f1)
 
-    def batch_read_csv_train(self, partial_fit_model, list_file_name, list_features, chunksize):
+    def get_train_file_name(self, file_path):
+        targetPattern = file_path + "**/**/*.gz"
+        # targetPattern = self.file_path + "*.json"
+        # return os.listdir(self.file_path)
+        return glob.glob(targetPattern)
+
+    def batch_read_csv_train(self, partial_fit_model, file_path, list_features, chunksize):
         self.DATA_TOTAL_ROW = 0
         self.VAL_POSITION_NUMBER = 0
         self.VAL_POSITION_NEGATIVE = 0
         
         self.DATA_TOTAL_ROW_VAL = 0
         epoch = 0
-        for file in list_file_name:
-            if "csv" in file or ".ipynb_checkpoints" in file:
-                del list_file_name[list_file_name.index(file)]
-
+        list_file_name = self.get_train_file_name(file_path)
         for file_name in list_file_name:
-            df_generator = pd.read_json(self.file_path + file_name, lines=True, chunksize=chunksize)
+            print(file_name)
+            # df_generator = pd.read_json(self.file_path + file_name, lines=True, chunksize=chunksize)
+            df_generator = pd.read_json(file_name, lines=True, chunksize=chunksize)
             for df in df_generator:
                 if epoch == 0:
                     self.df = df
